@@ -1,8 +1,15 @@
 from subprocess import Popen, PIPE
 
-COMMAND = u'caffeinate'
-ARGS = u" -d"
-BREAK = '\003'
+# See: https://ss64.com/osx/caffeinate.html
+COMMAND = u"caffeinate"
+
+ARGS = [
+    "-d",  # Prevent the display from sleeping.
+    "-u",  # Create an assertion to declare that user is active. If the dis-
+    # play is off, this option turns the display on and prevents the
+    # display from going into idle sleep.
+    "-t 2592000",  # Set timeout to 1-month (default is 5 seconds for -u option)
+]
 
 _process = None
 
@@ -19,14 +26,13 @@ def set_keepawake(keep_screen_awake=False):
     """
     if keep_screen_awake:
         global _process
-        _process = Popen([COMMAND], stdin=PIPE, stdout=PIPE)
+        _process = Popen([COMMAND] + ARGS, stdin=PIPE, stdout=PIPE)
     else:
-        _process = Popen(COMMAND + ARGS, stdin=PIPE, stdout=PIPE)
+        _process = Popen([COMMAND], stdin=PIPE, stdout=PIPE)
 
 
 def unset_keepawake():
     global _process
-    _process.stdin.write(BREAK)
-    _process.stdin.flush()
-    _process.stdin.close()
+
+    _process.terminate()
     _process.wait()
